==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ConstructorContext.h <==
// class gnu.java.beans.decoder.ConstructorContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3a61d506f2f71ad8 gnu_java_beans_decoder_AbstractCreatableObjectContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 3297494f2974bc57 gnu_java_beans_decoder_ConstructorContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractCreatableObjectContext

#include "gnu/java/beans/decoder/AbstractCreatableObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_ConstructorContext_H_
#define _JC_gnu_java_beans_decoder_ConstructorContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs	_jc_gnu_java_beans_decoder_ConstructorContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$refs	_jc_gnu_java_beans_decoder_ConstructorContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$nonrefs	_jc_gnu_java_beans_decoder_ConstructorContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$object	_jc_gnu_java_beans_decoder_ConstructorContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vmethods	_jc_gnu_java_beans_decoder_ConstructorContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vtable	_jc_gnu_java_beans_decoder_ConstructorContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vtype	_jc_gnu_java_beans_decoder_ConstructorContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$_init$ed29e6e80382d6fd(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$addParameterObjectImpl$a6c333697c3baaa7(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ConstructorContext$method$createObject$bd62db7229823e1e(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$addParameterObjectImpl$a6c333697c3baaa7;
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$createObject$bd62db7229823e1e;
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ConstructorContext$vmethods {
	void	(*addParameterObjectImpl$a6c333697c3baaa7)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*createObject$bd62db7229823e1e)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ConstructorContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	gnu_java_beans_decoder_AbstractCreatableObjectContext;
	_jc_gnu_java_beans_decoder_ConstructorContext$vmethods	gnu_java_beans_decoder_ConstructorContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ConstructorContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ConstructorContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs {
	struct _jc_java_util_ArrayList$object	*arguments;
	struct _jc_java_lang_Class$object	*klass;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ConstructorContext$refs {
    _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs	gnu_java_beans_decoder_ConstructorContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ConstructorContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs	gnu_java_beans_decoder_ConstructorContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ConstructorContext$object {
	_jc_gnu_java_beans_decoder_ConstructorContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ConstructorContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ConstructorContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ConstructorContext$vtype _jc_gnu_java_beans_decoder_ConstructorContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ConstructorContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ConstructorContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ConstructorContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ConstructorContext.h <==
// class gnu.java.beans.decoder.ConstructorContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class 3a61d506f2f71ad8 gnu_java_beans_decoder_AbstractCreatableObjectContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 3297494f2974bc57 gnu_java_beans_decoder_ConstructorContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractCreatableObjectContext

#include "gnu/java/beans/decoder/AbstractCreatableObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_ConstructorContext_H_
#define _JC_gnu_java_beans_decoder_ConstructorContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs	_jc_gnu_java_beans_decoder_ConstructorContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs	_jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$refs	_jc_gnu_java_beans_decoder_ConstructorContext$refs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$nonrefs	_jc_gnu_java_beans_decoder_ConstructorContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ConstructorContext$object	_jc_gnu_java_beans_decoder_ConstructorContext$object;

typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vmethods	_jc_gnu_java_beans_decoder_ConstructorContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vtable	_jc_gnu_java_beans_decoder_ConstructorContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ConstructorContext$vtype	_jc_gnu_java_beans_decoder_ConstructorContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$_init$ed29e6e80382d6fd(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$addParameterObjectImpl$a6c333697c3baaa7(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ConstructorContext$method$createObject$bd62db7229823e1e(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_ConstructorContext$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$addParameterObjectImpl$a6c333697c3baaa7;
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$createObject$bd62db7229823e1e;
extern _jc_method _jc_gnu_java_beans_decoder_ConstructorContext$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ConstructorContext$vmethods {
	void	(*addParameterObjectImpl$a6c333697c3baaa7)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*createObject$bd62db7229823e1e)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_ConstructorContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ConstructorContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$vmethods	gnu_java_beans_decoder_AbstractCreatableObjectContext;
	_jc_gnu_java_beans_decoder_ConstructorContext$vmethods	gnu_java_beans_decoder_ConstructorContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ConstructorContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ConstructorContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs {
	struct _jc_java_util_ArrayList$object	*arguments;
	struct _jc_java_lang_Class$object	*klass;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ConstructorContext$refs {
    _jc_gnu_java_beans_decoder_ConstructorContext$sub_refs	gnu_java_beans_decoder_ConstructorContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_refs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ConstructorContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractCreatableObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractCreatableObjectContext;
    _jc_gnu_java_beans_decoder_ConstructorContext$sub_nonrefs	gnu_java_beans_decoder_ConstructorContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ConstructorContext$object {
	_jc_gnu_java_beans_decoder_ConstructorContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ConstructorContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ConstructorContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ConstructorContext$vtype _jc_gnu_java_beans_decoder_ConstructorContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ConstructorContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ConstructorContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ConstructorContext_H_ */
